@@ -59,9 +59,9 @@
 #'                       label = agaricus.train$label)
 #' cv_folds <- KFold(agaricus.train$label, nfolds = 5,
 #'                   stratified = TRUE, seed = 0)
-#' xgb_cv_bayes <- function(max.depth, min_child_weight, subsample) {
+#' xgb_cv_bayes <- function(max_depth, min_child_weight, subsample) {
 #'   cv <- xgb.cv(params = list(booster = "gbtree", eta = 0.01,
-#'                              max_depth = max.depth,
+#'                              max_depth = max_depth,
 #'                              min_child_weight = min_child_weight,
 #'                              subsample = subsample, colsample_bytree = 0.3,
 #'                              lambda = 1, alpha = 0,
@@ -69,12 +69,12 @@
 #'                              eval_metric = "auc"),
 #'                data = dtrain, nround = 100,
 #'                folds = cv_folds, prediction = TRUE, showsd = TRUE,
-#'                early.stop.round = 5, maximize = TRUE, verbose = 0)
-#'   list(Score = cv$dt[, max(test.auc.mean)],
+#'                early_stopping_rounds = 5, maximize = TRUE, verbose = 0)
+#'   list(Score = cv$evaluation_log$test_auc_mean[cv$best_iteration],
 #'        Pred = cv$pred)
 #' }
 #' OPT_Res <- BayesianOptimization(xgb_cv_bayes,
-#'                                 bounds = list(max.depth = c(2L, 6L),
+#'                                 bounds = list(max_depth = c(2L, 6L),
 #'                                               min_child_weight = c(1L, 10L),
 #'                                               subsample = c(0.5, 0.8)),
 #'                                 init_grid_dt = NULL, init_points = 10, n_iter = 20,
@@ -147,9 +147,9 @@ BayesianOptimization <- function(FUN, bounds, init_grid_dt = NULL, init_points =
     # Printing History
     if (verbose == TRUE) {
       paste(c("elapsed", names(DT_history)),
-            c(format(This_Time["elapsed"], trim = FALSE, digits = 0, nsmall = 2),
-              format(DT_history[i, "Round", with = FALSE], trim = FALSE, digits = 0, nsmall = 0),
-              format(DT_history[i, -"Round", with = FALSE], trim = FALSE, digits = 0, nsmall = 4)),
+            c(format(This_Time["elapsed"], trim = FALSE, digits = NULL, nsmall = 2),
+              format(DT_history[i, "Round", with = FALSE], trim = FALSE, digits = NULL, nsmall = 0),
+              format(DT_history[i, -"Round", with = FALSE], trim = FALSE, digits = NULL, nsmall = 4)),
             sep = " = ", collapse = "\t") %>%
         cat(., "\n")
     }
@@ -190,9 +190,9 @@ BayesianOptimization <- function(FUN, bounds, init_grid_dt = NULL, init_points =
     # Printing History
     if (verbose == TRUE) {
       paste(c("elapsed", names(DT_history)),
-            c(format(Next_Time["elapsed"], trim = FALSE, digits = 0, nsmall = 2),
-              format(DT_history[j, "Round", with = FALSE], trim = FALSE, digits = 0, nsmall = 0),
-              format(DT_history[j, -"Round", with = FALSE], trim = FALSE, digits = 0, nsmall = 4)), sep = " = ", collapse = "\t") %>%
+            c(format(Next_Time["elapsed"], trim = FALSE, digits = NULL, nsmall = 2),
+              format(DT_history[j, "Round", with = FALSE], trim = FALSE, digits = NULL, nsmall = 0),
+              format(DT_history[j, -"Round", with = FALSE], trim = FALSE, digits = NULL, nsmall = 4)), sep = " = ", collapse = "\t") %>%
         cat(., "\n")
     }
   }
@@ -208,8 +208,8 @@ BayesianOptimization <- function(FUN, bounds, init_grid_dt = NULL, init_points =
   # Printing Best
   cat("\n Best Parameters Found: \n")
   paste(names(DT_history),
-        c(format(DT_history[which.max(Value), "Round", with = FALSE], trim = FALSE, digits = 0, nsmall = 0),
-          format(DT_history[which.max(Value), -"Round", with = FALSE], trim = FALSE, digits = 0, nsmall = 4)),
+        c(format(DT_history[which.max(Value), "Round", with = FALSE], trim = FALSE, digits = NULL, nsmall = 0),
+          format(DT_history[which.max(Value), -"Round", with = FALSE], trim = FALSE, digits = NULL, nsmall = 4)),
         sep = " = ", collapse = "\t") %>%
     cat(., "\n")
   # Return
